#
# News::Scan::Poster
#
# $Id: Poster.pm,v 1.1 1997/02/19 02:45:34 gbacon Exp gbacon $
#		Alan Jackson 12/97

package MailStats::Poster;

use strict;
use vars qw( $VERSION );

use Carp;

$VERSION = sprintf "%d.%02d", q$Revision: 1.0 $ =~ m#(\d+)\.(\d+)#;

sub new {
    my $proto = shift;
    my $class = ref($proto) || $proto;
    my $self  = {};
    my $art;

    croak "usage: ${class}->new(ARTICLE-OBJ)" unless @_ == 1;
    $art = shift;

    bless $self, $class;
    $self->address($art->author->address);

    my $author = $art->author;

    my $attrib = '';
    my $phrase;
    my $address;
    my $comment;

    $phrase  = $author->phrase;
    $address = $author->address;
    $comment = $author->comment;

    ## attempt to canonicalize addresses to PHRASE <ADDRESS>
    if ($phrase =~ /\S/) {
        $attrib = "$phrase <$address>";
    }
    elsif ($comment =~ /\S/) {
        $comment =~ s/^\((.*)\)$/$1/;
        $attrib = "$comment <$address>";
    }
    else {
        $attrib = $address;
    }
    $self->attrib($attrib);

    $self->volume($art->size);
    $self->articles(1);
    $self->header_volume($art->header_size);
    $self->body_volume($art->body_size);
    $self->body_words($art->body_words);
    $self->orig_volume($art->orig_size);
    $self->orig_words($art->orig_words);

    $self;
}

sub address {
    my $self = shift;

    if (@_) {
        $self->{address} = shift;
    }
    else {
        return $self->{address};
    }
}

sub attrib {
    my $self = shift;

    if (@_) {
        $self->{attrib} = shift;
    }
    else {
        return $self->{attrib};
    }
}

sub volume {
    my $self = shift;

    if (@_) {
        $self->{volume} = shift;
    }
    else {
        return $self->{volume};
    }
}

sub articles {
    my $self = shift;

    if (@_) {
        $self->{articles} = shift;
    }
    else {
        return $self->{articles};
    }
}

sub header_volume {
    my $self = shift;

    if (@_) {
        $self->{header_volume} = shift;
    }
    else {
        return $self->{header_volume};
    }
}

sub body_volume {
    my $self = shift;

    if (@_) {
        $self->{body_volume} = shift;
    }
    else {
        return $self->{body_volume};
    }
}

sub body_words {
    my $self = shift;

    if (@_) {
        $self->{body_words} = shift;
    }
    else {
        return $self->{body_words};
    }
}

sub orig_volume {
    my $self = shift;

    if (@_) {
        $self->{orig_volume} = shift;
    }
    else {
        return $self->{orig_volume};
    }
}

sub orig_words {
    my $self = shift;

    if (@_) {
        $self->{orig_words} = shift;
    }
    else {
        return $self->{orig_words};
    }
}

1;
